User Guide
============

Welcome to the MetaSynth User Guide. This section features everything you need to know about how to use MetaSynth. 
information on installation, quickstart, tutorials and information on the core features of the package.

.. toctree::
   :maxdepth: 1
   :caption: Sections:

   installation
   quick_start
   generating_metaframes
   exporting_metaframes
   generating_synthetic_data
   interactive_tutorials
   extensions